aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTom Ryder <tom@sanctum.geek.nz>2022-06-23 23:31:50 +1200
committerTom Ryder <tom@sanctum.geek.nz>2022-06-23 23:31:50 +1200
commit1becbb42661b5fbf8e1ab54c4074388769f09ec7 (patch)
treee65d2991ad5231bc6e319e60977a5687b92b08f9
parentMove Caps-Ctrl modifier into .keyboard file (diff)
downloaddotfiles-1becbb42661b5fbf8e1ab54c4074388769f09ec7.tar.gz
dotfiles-1becbb42661b5fbf8e1ab54c4074388769f09ec7.zip
Revert "Move Caps-Ctrl modifier into .keyboard ...
This reverts commit 8c23582694eed17689dd2192305c895b961344bf. This doesn't work the way I thought it did. I'll try something else later.
-rw-r--r--Makefile1
-rw-r--r--x/keyboard10
-rw-r--r--x/xsession.sh6
3 files changed, 4 insertions, 13 deletions
diff --git a/Makefile b/Makefile
index e0f4b5f2..aa4d8ed1 100644
--- a/Makefile
+++ b/Makefile
@@ -669,7 +669,6 @@ install-x: x/xsession check-xsession install-logrotate
cp -p -- x/xsession $(HOME)/.xsession
cp -p -- x/Xresources $(HOME)/.Xresources
cp -p -- x/Xresources.d/* $(HOME)/.Xresources.d
- cp -p -- x/keyboard $(HOME)/.keyboard
cp -p -- x/logrotate/config.d/* $(XDG_CONFIG_HOME)/logrotate/config.d
install-yt-dlp install-youtube-dl:
diff --git a/x/keyboard b/x/keyboard
deleted file mode 100644
index 385f3530..00000000
--- a/x/keyboard
+++ /dev/null
@@ -1,10 +0,0 @@
-# Import the system keyboard settings...
-. /etc/default/keyboard
-
-# ...but then make Caps Lock act as Control, just for us. I feel like
-# caps:ctrl_modifier is a better option name to describe the intent here, and
-# it works fine in X, but not on the console.
-#
-XKBOPTIONS=ctrl:nocaps
-
-# We set X-specific options in ~/.xsession.
diff --git a/x/xsession.sh b/x/xsession.sh
index 805d8ef1..c0b5cb1c 100644
--- a/x/xsession.sh
+++ b/x/xsession.sh
@@ -20,12 +20,14 @@ xargs xrandr \
xargs xwallpaper \
< "${XDG_CONFIG_HOME:-"$HOME"/.config}"/xwallpaper/config &
-# Add a couple more options to any set in ~/.keyboard:
+# Set a few keyboard map options:
#
# - Remap right Alt as an X Compose key.
# - Kill X server with Ctrl+Alt+Backspace.
#
setxkbmap \
+ -option caps:ctrl_modifier \
-option compose:ralt \
-option terminate:ctrl_alt_bksp \
&
@@ -20,12 +20,14 @@ xargs xrandr \
#
-# - Remap right Alt as an X Compose key.
+# - Remap Caps Lock as another Control key.
+# - Remap right Alt as a Compose key.
# - Kill X server with Ctrl+Alt+Backspace.
#